@@ -84,7 +84,7 @@ short_description["set_width"] = lambda: _("Sets the output width in some modes.
 local_helpers = {"dark": dark, "light": light, "set_width": set_width}
 add_help_attribute(local_helpers)
 for helper in local_helpers:
-    Friendly.add_helper(helper, local_helpers[helper])
+    Friendly.add_helper(local_helpers[helper])
 
 helpers.update(local_helpers)
 __all__ = list(helpers.keys())
